"""envia

Did you ever lost track of which environment variables you need to
configure your package? Envia solves this problem.

You can import EnvVar and keep track of the variables you need.
"""

from envia.env import EnvVar
from envia.errors import MissingEnvironmentVariable
